summaryrefslogtreecommitdiffstats
path: root/karbon/widgets/vsmallpreview.cc
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/widgets/vsmallpreview.cc')
-rw-r--r--karbon/widgets/vsmallpreview.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/karbon/widgets/vsmallpreview.cc b/karbon/widgets/vsmallpreview.cc
index 1cd6af0e..6e35d921 100644
--- a/karbon/widgets/vsmallpreview.cc
+++ b/karbon/widgets/vsmallpreview.cc
@@ -22,7 +22,7 @@
#include <tqcolor.h>
#include <tqframe.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpixmap.h>
#include <klocale.h>
@@ -42,21 +42,21 @@
VSmallPreview::VSmallPreview( TQWidget* parent, const char* name )
: TQWidget( parent, name )
{
- /* Create widget layout */
- TQHBoxLayout *layout = new TQHBoxLayout( this, 4 );
+ /* Create widget tqlayout */
+ TQHBoxLayout *tqlayout = new TQHBoxLayout( this, 4 );
m_strokeLabel = new TQLabel( i18n( "Stroke: None" ), this );
- layout->addWidget( m_strokeLabel );
+ tqlayout->addWidget( m_strokeLabel );
m_strokeFrame = new TQFrame( this );
m_strokeFrame->setFixedWidth ( FRAMEWIDTH );
m_strokeFrame->setFrameStyle( TQFrame::GroupBoxPanel | TQFrame::Plain );
- layout->addWidget( m_strokeFrame );
+ tqlayout->addWidget( m_strokeFrame );
m_fillLabel = new TQLabel( i18n( "Fill: None" ), this );
- layout->addWidget( m_fillLabel );
+ tqlayout->addWidget( m_fillLabel );
m_fillFrame = new TQFrame( this );
m_fillFrame->setFixedWidth ( FRAMEWIDTH );
m_fillFrame->setFrameStyle( TQFrame::GroupBoxPanel | TQFrame::Plain );
- layout->addWidget( m_fillFrame );
- layout->activate();
+ tqlayout->addWidget( m_fillFrame );
+ tqlayout->activate();
m_fill = VFill();
m_stroke = VStroke();